@@ -47,9 +47,6 @@ from markupsafe import Markup
 import asyncio
 from abc import ABC
 from functools import cache
-from dataclasses import dataclass, field
-from enum import Enum
-from typing import Optional, Union, NamedTuple, List
 
 from metadoctor import enumeration
 from metadoctor import element
@@ -381,7 +378,7 @@ class BaseField(ABC):
         return value
     
     def submit_button(self):
-        return str(Input(ftype='submit', style=SUBMIT_STYLE))
+        return str(Input(ftype='submit', style=INPUT_STYLE))
 
     def get_formfield_attrs(self, novalue=False) -> str:
         result = [f'id="{self.public_name}" name="{self.public_name}"']
@@ -902,7 +899,7 @@ class ArrayOfKeys(ReferenceField):
 
 class BaseManager(ABC):
     
-    def __init__(self, user: User = None, connection: Connection = None) -> None:
+    def __init__(self, user = None, connection: Connection = None) -> None:
         self.user = user
         self.connection = connection or Connection()
     
