@@ -39,7 +39,7 @@ class Settings:
         self.chain.update(data)
 
     def get(self, key):
-        return Secret(self.chain.get(key))
+        return self.chain.get(key)
     
     def all_chain(self):
         return self.chain
